# Shuttle
Cross-chain atomic swaps between the networks of two cryptocurrencies.

## Installation
PIP to install shuttle globally. For Linux sudo may be required.
```
$ pip install pyshuttle
```

## Development
We welcome pull requests. To get started, just fork this repo, clone it locally, and run:
```
$ pip install -e . -r requirements.txt
```

## Testing
Tests are still under development.

You can run the tests with:

```
$ pytest tests
```

Or use `tox` to run the complete suite against the full set of build targets, or pytest to run specific 
tests against a specific version of Python.

## Contributing
Feel free to open an issue if you find a problem, or a pull request if you've solved an issue.

## Meta

Meheret Tesfaye – [@meherett](https://github.com/meherett) – meherett@zoho.com

Distributed under the AGPL-3.0 license. See ``LICENSE`` for more information.

For the versions available, see the [tags on this repository](https://github.com/meherett/shuttle/tags).

## License
[AGPL-3.0](https://github.com/meherett/shuttle/LICENSE)
